Revert "Revert "Full-stack integrity: check vdex contents.""

bug: 30972906

Initial revert due to 'check' file of the test needing updating for target tests.

This reverts commit a19b7649faf8780737be7ce3ec48a12d81c6d69f.

Change-Id: I455780bd88cd89ff80c9084d399e2beeb819b95f
diff --git a/dex2oat/dex2oat.cc b/dex2oat/dex2oat.cc
index 3732b17..1578656 100644
--- a/dex2oat/dex2oat.cc
+++ b/dex2oat/dex2oat.cc
@@ -457,7 +457,7 @@
   UsageError("  --deduplicate-code=true|false: enable|disable code deduplication. Deduplicated");
   UsageError("      code will have an arbitrary symbol tagged with [DEDUPED].");
   UsageError("");
-  UsageError("  --copying-dex-files=true|false: enable|disable copying the dex files into the");
+  UsageError("  --copy-dex-files=true|false: enable|disable copying the dex files into the");
   UsageError("      output vdex.");
   UsageError("");
   UsageError("  --compilation-reason=<string>: optional metadata specifying the reason for");
@@ -2921,8 +2921,9 @@
   // Whether the given input vdex is also the output.
   bool update_input_vdex_ = false;
 
-  // By default, copy the dex to the vdex file.
-  bool copy_dex_files_ = true;
+  // By default, copy the dex to the vdex file only if dex files are
+  // compressed in APK.
+  CopyOption copy_dex_files_ = CopyOption::kOnlyIfCompressed;
 
   // The reason for invoking the compiler.
   std::string compilation_reason_;